@@ -40,7 +40,7 @@
 /**
  * Change itc FD options to be non-blocking.
  *
- * @param pip the pipe to manipulate
+ * @param itc the inter-thread communication primitive to manipulate
  * @return non-zero if succeeded, zero otherwise
  */
 int
@@ -58,7 +58,7 @@ MHD_itc_nonblocking_ (struct MHD_itc_ itc)
       return 0;
 
     if ( ((flags | O_NONBLOCK) != flags) &&
-         (0 != fcntl (pip.fd[i],
+         (0 != fcntl (itc.fd[i],
                       F_SETFL,
                       flags | O_NONBLOCK)) )
       return 0;
